class GlobalConsts:
    def __init__(self) -> None:
        self.MAX_BYTES = 65535
        self.server_port = 9908
        self.apiPath = "http://127.0.0.1:9908/net_api"
        self.selfUsername = "";


from src.Displayers.displayer import Displayer
import pickle

class Processor:
    def __init__(self) -> None:
        self.Displayer = Displayer
    
    def processMessage(self, data):

        obj = pickle.loads(data)

        try:    
            Displayer.displayMessage(obj)
        except:
            Displayer.displayExcpetionMessage(obj)
    
    def processMessageAuth(selfd, selfport, connectionData, self_server):

        lst = list(connectionData.connectionSelfHost)
        lst[1] = int(selfport)
        connectionData.connectionSelfHost = tuple(lst)
        self_server(connectionData.connectionSelfHost)

    def processSendMessageToPort(self, client_sock, connectionData, recieverPort, new_obj):

        # new_obj = {"username": selfUsername, "message": message_to_send}
        message = pickle.dumps(new_obj)
        lst = list(connectionData.connectionHostToPeer)
        lst[1] = int(recieverPort)
        connectionHostToPeer = tuple(lst)
        client_sock.sendto(message, connectionHostToPeer)


from flask import Flask, jsonify, request
from flask_restful import reqparse, abort, Api, Resource

class Parser:
    
    def __init__(self) -> None:
        self.parser = reqparse.RequestParser()
        self.parser.add_argument('username', type=str)
        self.parser.add_argument('message', type=str)
        self.parser.add_argument('reciever', type=str)


class Displayer:
    def __init__(self) -> None:
        pass

    @staticmethod
    def displayMessage(obj):
        print(">>> " + obj["username"] + ": " + obj["message"])

    @staticmethod
    def displayExcpetionMessage(obj):
        print("--------> Exception")
        print("--------> OnException Message -----> " + str(obj))

    @staticmethod
    def logMessage(obj, func_name):
        print("[LOG] Message From --> " + str(func_name))
        print("[LOG] [TIME] >>> " + obj)


from typing import Mapping
from src_server.DatabaseManager import *
from src_server.Globals.globalConsts import GlobalConsts

class MainConfiguration:
    def __init__(self) -> None:
        self.red = RedisController().red
        self.globalConsts = GlobalConsts()

    def configureApp(self):
        self.red.flushdb()
        self.red.set("next_client_port", self.globalConsts.server_port + 1)